@@ -57,7 +57,6 @@ def install():
             # resp = _original_falcon_api(this, env, start_response)
             # span.op = str(req.url).split("?")[0]
             span.op = functions.getUri(str(req.url).split("?")[0])
-            # functions.log("falcon url:%s,op:%s", str(req.url), span.op)
             span.peer = "%s:%s" % (req.remote_addr, req.port)
             span.tag(Tag(key=tags.HttpMethod, val=req.method))
             span.tag(Tag(key=tags.HttpUrl, val=str(req.url)))
@@ -74,7 +73,6 @@ def install():
             set_code(config.service_version_reader,req,"service_version")
 
             resp_status = parse_status(resp_obj.status)
-            functions.log("resp_status:%s", str(resp_status[0]))
 
             if int(resp_status[0]) >= 400:
                 span.error_occurred = True
@@ -170,13 +168,10 @@ def get_headers(env):
                 value_arr = value.split("-")
                 if len(value_arr) > 0:
                     headers[header_key] = lang.b64decode(value_arr[0])
-                    # functions.log("header_key:%s,value:%s",header_key,headers[header_key])
                     if len(value_arr) >= 2:
                         headers["parent_id"] = lang.b64decode(value_arr[1])
-                        # functions.log("header_key:%s,value:%s",header_key,headers["parent_id"])
             else:
                 headers[header_key] = value
-                # functions.log("header_key:%s,value:%s",header_key,value)
         elif name in wsgi_content_headers:
             headers[name.replace("_", "-")] = value
 
@@ -189,5 +184,4 @@ def parse_status(status_str):
     :param status_str:
     :return:
     """
-    functions.log("status_str:%s",status_str)
     return status_str.split(" ") if status_str else [404, "status is empty"]
